@@ -3,6 +3,8 @@ package Thruk::Agents::SNClient::Checks::Memory;
 use warnings;
 use strict;
 
+use Thruk::Agents::SNClient ();
+
 =head1 NAME
 
 Thruk::Agents::SNClient::Checks::Memory - returns memory checks for snclient
@@ -26,13 +28,18 @@ sub get_checks {
 
     return unless $inventory->{'memory'};
 
+    my $mem_args = ["type=physical"];
+    if(Thruk::Agents::SNClient::has_agent_min_version($inventory, 'v0.41.0051')) {
+        push @{$mem_args}, '-n', '6';
+    }
+
     for my $mem (@{$inventory->{'memory'}}) {
         if($mem->{'type'} eq 'physical') {
             push @{$checks}, {
                 'id'     => 'mem',
                 'name'   => 'memory',
                 'check'  => 'check_memory',
-                'args'   => { "type" => "physical" },
+                'args'   => $mem_args,
                 'parent' => 'agent version',
                 'info'   => $mem,
             };
